@@ -5,7 +5,7 @@ import pandas as pd
 from cognite.air import AIRClient
 from cognite.air.utils import is_string_truthy
 from cognite.client.data_classes import Event, EventList
-from cognite.client.exceptions import CogniteDuplicatedError
+from cognite.client.exceptions import CogniteDuplicatedError, CogniteNotFoundError
 
 from .ts_utils import current_time_in_ms
 
@@ -299,6 +299,21 @@ def send_notification(start_time: int, end_time: int, alert_window: int, min_len
     return is_event_fresh and is_event_long
 
 
+def update_events(client, events):
+    for event in events:
+        try:
+            client.events.update(event)
+        except CogniteNotFoundError:
+            asset_ids = event.asset_ids
+            correct_asset_ids = []
+            for asset_id in asset_ids:
+                asset = client.assets.retrieve(asset_id)
+                if asset is not None:
+                    correct_asset_ids.append(asset.id)
+            event.asset_ids = correct_asset_ids
+            client.events.update(event)
+
+
 def create_alerts(
     air_client: AIRClient,
     df: pd.DataFrame,
@@ -342,15 +357,11 @@ def create_alerts(
     # check if events need to be updated and update
     if len(events_to_be_updated) > 0:
         print(f"trying to close {len(events_to_be_updated)} events.")
-        for event in events_to_be_updated:
-            print(event.id)
-            air_client._config.client.events.update(event)
+        update_events(air_client._config.client, events_to_be_updated)
         if len(new_events) == 0:
-            print("no new events")
             return events_to_be_updated, [], end_point
     # if there are no new events left return nothing
     elif len(new_events) == 0:
-        print("nothing to write")
         return [], [], end_point
 
     # remove duplicates
